@@ -31,15 +31,13 @@ the other.
 _Any change the user.json format must be met with a version bump._
 """
 from typing import Any, Dict
-from mitosheet.experiments.experiment_utils import get_current_experiment, get_new_experiment
-from mitosheet._version import package_name
 
 from mitosheet.user.db import get_user_json_object, set_user_json_object
-from mitosheet.user.schemas import (UJ_AI_MITO_API_NUM_USAGES, UJ_AI_PRIVACY_POLICY, UJ_CLOSED_FEEDBACK, UJ_EXPERIMENT, UJ_FEEDBACKS_V2,
-                                    UJ_INTENDED_BEHAVIOR, UJ_MITOSHEET_ENTERPRISE,
+from mitosheet.user.schemas import (UJ_CLOSED_FEEDBACK, UJ_FEEDBACKS_V2,
+                                    UJ_INTENDED_BEHAVIOR,
                                     UJ_MITOSHEET_LAST_FIFTY_USAGES,
                                     UJ_MITOSHEET_LAST_FIVE_USAGES,
-                                    UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY, UJ_RECEIVED_CHECKLISTS,
+                                    UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY,
                                     UJ_USER_JSON_VERSION, USER_JSON_DEFAULT,
                                     USER_JSON_VERSION_1)
 
@@ -142,86 +140,6 @@ def upgrade_user_json_version_4_to_5(user_json_version_4: Dict[str, Any]) -> Dic
         user_json_version_4[UJ_MITOSHEET_PRO] = False
     return user_json_version_4
 
-def upgrade_user_json_version_5_to_6(user_json_version_5: Dict[str, Any]) -> Dict[str, Any]:
-    """
-    Just adds the UJ_EXPERIMENT field, and sets it equal to
-    the default expirments list
-    """
-    # First, bump the version number
-    user_json_version_5[UJ_USER_JSON_VERSION] = 6
-
-    # Then, set new field
-    if UJ_EXPERIMENT not in user_json_version_5:
-        user_json_version_5[UJ_EXPERIMENT] = get_new_experiment()
-
-    return user_json_version_5
-
-def upgrade_user_json_version_6_to_7(user_json_version_6: Dict[str, Any]) -> Dict[str, Any]:
-    """
-    Just adds the UJ_RECEIVED_CHECKLISTS field, and sets it equal to the full onboarding
-    checklist. This is because we do not want users to have to go back and do the onboarding
-    checklist if they are already onboarded.
-
-    We only upgrade them if they are not on the installer_communication_and_time_to_value 
-    experiment, as this means that they have used the installer, and we actually _want_
-    them to go through the onboarding checklist.
-
-    We also count the checklist as completed if the user is on mitosheet-private, as this upgrade
-    does not happen through the installer, and so this experiment id will be set, but we do not
-    want these users to go through the checklist. This is a temporary fix, and we need a much better
-    long-term solution going forward.
-
-    NOTE: We no longer have the onboarding checklist, but we don't edit this function as there
-    is no need to.
-    """
-    # First, bump the version number
-    user_json_version_6[UJ_USER_JSON_VERSION] = 7
-
-    # Then, set new field
-    if UJ_RECEIVED_CHECKLISTS not in user_json_version_6:
-        current_experiment = user_json_version_6[UJ_EXPERIMENT]
-        if current_experiment['experiment_id'] != 'installer_communication_and_time_to_value' or package_name == 'mitosheet-private':
-            user_json_version_6[UJ_RECEIVED_CHECKLISTS] = {
-                "onboarding_checklist": ['signup', 'import', 'filter', 'pivot', 'graph', 'finalize']
-            }
-        else:
-            user_json_version_6[UJ_RECEIVED_CHECKLISTS] = {}
-
-
-    return user_json_version_6
-
-def upgrade_user_json_version_7_to_8(user_json_version_7: Dict[str, Any]) -> Dict[str, Any]:
-    """
-    Adds the UJ_MITOSHEET_ENTERPRISE key, and sets it to False
-    """
-    # First, bump the version number
-    user_json_version_7[UJ_USER_JSON_VERSION] = 8
-
-    # Then, add the new enterprise key
-    user_json_version_7[UJ_MITOSHEET_ENTERPRISE] = False
-
-    return user_json_version_7
-
-def upgrade_user_json_version_8_to_9(user_json_version_8: Dict[str, Any]) -> Dict[str, Any]:
-    """
-    Adds the UJ_AI_PRIVACY_POLICY key, and sets it to False
-    """
-    user_json_version_8[UJ_USER_JSON_VERSION] = 9
-
-    user_json_version_8[UJ_AI_PRIVACY_POLICY] = False
-
-    return user_json_version_8
-
-def upgrade_user_json_version_9_to_10(user_json_version_9: Dict[str, Any]) -> Dict[str, Any]:
-    """
-    Adds the U key, and sets it to False
-    """
-    user_json_version_9[UJ_USER_JSON_VERSION] = 10
-
-    user_json_version_9[UJ_AI_MITO_API_NUM_USAGES] = 0
-
-    return user_json_version_9
-
 def try_upgrade_user_json_to_current_version() -> None:
     user_json_object = get_user_json_object()
 
@@ -245,22 +163,6 @@ def try_upgrade_user_json_to_current_version() -> None:
         user_json_object = upgrade_user_json_version_3_to_4(user_json_object)
     if user_json_object[UJ_USER_JSON_VERSION] == 4:
         user_json_object = upgrade_user_json_version_4_to_5(user_json_object)
-    if user_json_object[UJ_USER_JSON_VERSION] == 5:
-        user_json_object = upgrade_user_json_version_5_to_6(user_json_object)
-    if user_json_object[UJ_USER_JSON_VERSION] == 6:
-        user_json_object = upgrade_user_json_version_6_to_7(user_json_object)
-    if user_json_object[UJ_USER_JSON_VERSION] == 7:
-        user_json_object = upgrade_user_json_version_7_to_8(user_json_object)
-    if user_json_object[UJ_USER_JSON_VERSION] == 8:
-        user_json_object = upgrade_user_json_version_8_to_9(user_json_object)
-    if user_json_object[UJ_USER_JSON_VERSION] == 9:
-        user_json_object = upgrade_user_json_version_9_to_10(user_json_object)
-
-    # We always make sure that the experiment is the most up to date
-    # version of the experiment
-    new_experiment = get_new_experiment()
-    if new_experiment is not None and user_json_object[UJ_EXPERIMENT]['experiment_id'] != new_experiment['experiment_id']:
-            user_json_object[UJ_EXPERIMENT] = new_experiment
 
     set_user_json_object(user_json_object)
 
